import cv2
import numpy as np


def main():
    cap = cv2.VideoCapture('/Users/worksitevision/Documents/worker/stream/croptest.mp4')
    frameNo = 0
    while cap.isOpened():
        ret, frame = cap.read()
        if np.shape(frame) == ():
            break
        else:
            cv2.imshow("frame", frame)
            camera_movement(frame,frameNo)
            if cv2.waitKey(1) & 0xFF == ord('q'):
                break

    cap.release()
    cv2.destroyAllWindows()


def average(liste):
    return int(sum(liste) / len(liste))


def camera_movement(frame, frameNo):
    b = list()
    g = list()
    r = list()
    for y in range(1175, 1225):
        for x in range(175, 225):
            b.append(frame[x, y, 0])  # B Channel Value
            g.append(frame[x, y, 1])  # G Channel Value
            r.append(frame[x, y, 2])  # R Channel Value

    averageB = average(b)  # average of list b
    averageG = average(g)  # average of list g
    averageR = average(r)  # average of list r
    print('Frame: {0}, B:{1}, G:{2}, R:{3}.'.format(frameNo, averageB, averageG, averageR))
    frameNo += 1

    # bgr value of fixed point at sea (209,124,38)
    if 195 < averageB < 215 and 115 < averageG < 135 and 25 < averageR < 50:
        print("Kamera sabit.")
    else:
        print("Kamera hareket etti")


if __name__ == "__main__":
    main()



import math


class EuclideanDistTracker:
    def __init__(self):
        # Store the center positions of the objects
        self.center_points = {}
        # Keep the count of the IDs
        # each time a new object id detected, the count will increase by one
        self.id_count = 0

    def update(self, objects_rect):
        # Objects boxes and ids
        objects_bbs_ids = []

        # Get center point of new object
        for rect in objects_rect:
            x, y, w, h = rect
            cx = (x + x + w) // 2
            cy = (y + y + h) // 2

            # Find out if that object was detected already
            same_object_detected = False
            for id, pt in self.center_points.items():
                dist = math.hypot(cx - pt[0], cy - pt[1])

                if dist < 250:
                    self.center_points[id] = (cx, cy)
                    objects_bbs_ids.append([x, y, w, h, id])
                    same_object_detected = True
                    break

            # New object is detected we assign the ID to that object
            if same_object_detected is False:
                self.center_points[self.id_count] = (cx, cy)
                objects_bbs_ids.append([x, y, w, h, self.id_count])
                self.id_count += 1

        # Clean the dictionary by center points to remove IDS not used anymore
        new_center_points = {}
        for obj_bb_id in objects_bbs_ids:
            _, _, _, _, object_id = obj_bb_id
            center = self.center_points[object_id]
            new_center_points[object_id] = center

        # Update dictionary with IDs not used removed
        self.center_points = new_center_points.copy()
        return objects_bbs_ids , self.center_points



import os
import cv2
import datetime


def merge_videos(listdir_path:str, file_endswith:str, frame_rate:float):
    # Merge multiple videos
    # Define output video variables first
    out = cv2.VideoWriter(
        str(listdir_path + datetime.datetime.now().strftime("%H-%M-%S")) + '__merged__' + '.mp4',
        cv2.VideoWriter_fourcc(*'MP4V'),
        frame_rate, # Frame rate of the new video
        (2560, 1440) # w,h value of the video
    )
    # List files in folder.
    for file in sorted(os.listdir(listdir_path)):
        # Get only mp4 files
        if file.endswith(file_endswith):
            print('File merging :' + file)
            cap = cv2.VideoCapture(listdir_path + file)
            while True:
                ret, frame = cap.read()
                if ret is True:
                    out.write(frame)
                else:
                    print(file + ' added.')
                    break


if __name__ == "__main__":
    merge_videos(
        listdir_path='../storage/',
        file_endswith='.mp4',
        frame_rate=15.0
    )



from setuptools import setup
import pathlib
import builtins

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='elma_armut_uzay',
    version='2.0.1',
    user='iremdgnc',
    packages=['stream'],  # Required
    license='Apache License 2.0',
    download_url='https://github.com/kbingol/worker.git'
)
